@@ -5,6 +5,7 @@
 #include "FirebaseMessaging.h"
 #include "FirebaseRemoteConfig.h"
 #include "FirebaseMLKit.h"
+#include "FirebaseFirestore.h"
 
 typedef struct {
 	PyObject_HEAD
@@ -36,9 +37,15 @@ typedef struct {
 		FirebaseMLKit* firebaseMLKit;
 } firebaseMLKit_obj;
 
+typedef struct {
+	PyObject_HEAD
+		FirebaseFirestore* firebaseFirestore;
+} firebaseFirestore_obj;
+
 extern PyTypeObject FirebaseType;
 extern PyTypeObject FirebaseAnalyticsType;
 extern PyTypeObject FirebaseAuthType;
 extern PyTypeObject FirebaseMessagingType;
 extern PyTypeObject FirebaseRemoteConfigType;
 extern PyTypeObject FirebaseMLKitType;
+extern PyTypeObject FirebaseFirestoreType;
\ No newline at end of file
