@@ -20,6 +20,12 @@ PyDoc_STRVAR(firebaseIsReady_doc,
     "\n"\
     "firebase.isReady()");
 
+//firebase update
+PyDoc_STRVAR(firebaseUpdate_doc,
+    "update the firebase system\n"\
+    "\n"\
+    "firebase.update()");
+
 //firebase testcase
 PyDoc_STRVAR(firebaseTestcase_doc,
 	"The testcase for firebase\n"\
@@ -333,3 +339,53 @@ PyDoc_STRVAR(firebaseMLKitSetContourList_doc,
 	"Parameters\n"\
 	"----------\n"\
 	"    value : list");
+
+//firebase firestore init
+PyDoc_STRVAR(firebaseFirestoreInit_doc,
+	"init the Firebase Firestore system \n"\
+	"\n"\
+	"firebaseFirestore.init()");
+
+//firebase firestore release
+PyDoc_STRVAR(firebaseFirestoreRelease_doc,
+	"release the Firebase Firestore system\n"\
+	"\n"\
+	"firebaseFirestore.release()");
+
+//firebase firestore get
+PyDoc_STRVAR(firebaseFirestoreGet_doc,
+	"get data with Cloud Firestore\n"\
+	"\n"\
+	"firestore().get(collection, field, callback)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    collection : string\n"\
+	"    field : string or None\n"\
+	"    callback : function(collection, field, value)\n"\
+			"value : (string, int, double, dictionary)");
+
+//firebase firestore set
+PyDoc_STRVAR(firebaseFirestoreSet_doc,
+	"add data to Cloud Firestore\n"\
+	"\n"\
+	"firestore().set(collection, field, value, callback)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    collection : string\n"\
+	"    field : string\n"\
+	"    value : (string, int, double, dictionary)\n"\
+	"    callback : optional function(collection, field, result)");
+
+//firebase firestore delete
+PyDoc_STRVAR(firebaseFirestoreDelete_doc,
+	"delete data from Cloud Firestore\n"\
+	"\n"\
+	"firestore().get(collection, field, callback)\n"\
+	"\n"\
+	"Parameters\n"\
+	"----------\n"\
+	"    collection : string\n"\
+	"    field : string or None\n"\
+	"    callback : optional function(collection, field, result)");
\ No newline at end of file
